@@ -1,4 +1,5 @@
 # misc. file io concerned subroutines
+# $Id: fio.pl,v 1.1.1.1 2000/03/18 06:54:10 odakker Exp $
 # Copyright (c) TOYODA Eizi, 1998.  All rights reserved.
 # see COPYING.TXT for terms of license.
 
@@ -6,11 +7,19 @@
 sub creat {
 	local($fnam) = @_;
 	local($parent) = $fnam;
+	&CheckUmask;
 	&mkdir($parent) if ($parent =~ s/\/[^\/]+$//);
 	open($fnam, ">$fnam") || &die("creat $fnam");
 	$fnam;
 }
 
+sub CheckUmask {
+	return unless ((umask) & 0660);
+	local($umask) = (umask) & ~0660;
+	&warn(sprintf("warning: umask set to %04lo\n", $umask));
+	umask $umask;
+}
+
 sub mkdir {
 	local($dnam) = @_;
 	return if (-d $dnam);
